@@ -520,10 +520,14 @@ def debug_dump(ctx, cli_obj, db, photos_library, dump, uuid):
             print("_dbkeywords_uuid:")
             pprint.pprint(photosdb._dbkeywords_uuid)
         elif attr == "persons":
-            print("_dbfaces_person:")
-            pprint.pprint(photosdb._dbfaces_person)
             print("_dbfaces_uuid:")
             pprint.pprint(photosdb._dbfaces_uuid)
+            print("_dbfaces_pk:")
+            pprint.pprint(photosdb._dbfaces_pk)
+            print("_dbpersons_pk:")
+            pprint.pprint(photosdb._dbpersons_pk)
+            print("_dbpersons_fullname:")
+            pprint.pprint(photosdb._dbpersons_fullname)
         elif attr == "photos":
             if uuid:
                 for uuid_ in uuid:
@@ -1146,6 +1150,18 @@ def query(
     '--keyword-template "{created.year}" '
     "See Templating System below.",
 )
+@click.option(
+    "--description-template",
+    metavar="TEMPLATE",
+    multiple=False,
+    default=None,
+    help="For use with --exiftool, --sidecar; specify a template string to use as "
+    "description in the form '{name,DEFAULT}' "
+    "This is the same format as --directory.  For example, if you wanted to append "
+    "'exported with osxphotos on [today's date]' to the description, you could specify "
+    '--description-template "{descr} exported with osxphotos on {today.date}" '
+    "See Templating System below.",
+)
 @click.option(
     "--current-name",
     is_flag=True,
@@ -1260,6 +1276,7 @@ def export(
     person_keyword,
     album_keyword,
     keyword_template,
+    description_template,
     current_name,
     sidecar,
     only_photos,
@@ -1505,6 +1522,7 @@ def export(
                     album_keyword=album_keyword,
                     person_keyword=person_keyword,
                     keyword_template=keyword_template,
+                    description_template=description_template,
                     export_db=export_db,
                     fileutil=fileutil,
                     dry_run=dry_run,
@@ -1541,6 +1559,7 @@ def export(
                         album_keyword=album_keyword,
                         person_keyword=person_keyword,
                         keyword_template=keyword_template,
+                        description_template=description_template,
                         export_db=export_db,
                         fileutil=fileutil,
                         dry_run=dry_run,
@@ -2012,6 +2031,7 @@ def export_photo(
     album_keyword=None,
     person_keyword=None,
     keyword_template=None,
+    description_template=None,
     export_db=None,
     fileutil=FileUtil,
     dry_run=None,
@@ -2039,6 +2059,7 @@ def export_photo(
         album_keyword: boolean; if True, exports album names as keywords in metadata
         person_keyword: boolean; if True, exports person names as keywords in metadata
         keyword_template: list of strings; if provided use rendered template strings as keywords
+        description_template: string; optional template string that will be rendered for use as photo description
         export_db: export database instance compatible with ExportDB_ABC
         fileutil: file util class compatible with FileUtilABC
         dry_run: boolean; if True, doesn't actually export or update any files
@@ -2113,6 +2134,7 @@ def export_photo(
                 use_albums_as_keywords=album_keyword,
                 use_persons_as_keywords=person_keyword,
                 keyword_template=keyword_template,
+                description_template=description_template,
                 update=update,
                 export_db=export_db,
                 fileutil=fileutil,
@@ -2168,6 +2190,7 @@ def export_photo(
                         use_albums_as_keywords=album_keyword,
                         use_persons_as_keywords=person_keyword,
                         keyword_template=keyword_template,
+                        description_template=description_template,
                         update=update,
                         export_db=export_db,
                         fileutil=fileutil,
