@@ -29,6 +29,7 @@ from .._constants import (
     _PHOTOS_5_SHARED_PHOTO_PATH,
 )
 from ..albuminfo import AlbumInfo
+from ..personinfo import PersonInfo
 from ..phototemplate import PhotoTemplate
 from ..placeinfo import PlaceInfo4, PlaceInfo5
 from ..utils import _debug, _get_resource_loc, findfiles, get_preferred_uti_extension
@@ -339,7 +340,18 @@ class PhotoInfo:
     @property
     def persons(self):
         """ list of persons in picture """
-        return self._info["persons"]
+        return [self._db._dbpersons_pk[pk]["fullname"] for pk in self._info["persons"]]
+
+    @property
+    def person_info(self):
+        """ list of PersonInfo objects for person in picture """
+        try:
+            return self._personinfo
+        except AttributeError:
+            self._personinfo = [
+                PersonInfo(db=self._db, pk=pk) for pk in self._info["persons"]
+            ]
+            return self._personinfo
 
     @property
     def albums(self):
@@ -642,7 +654,49 @@ class PhotoInfo:
             otherwise returns False """
         return self._info["raw_is_original"]
 
-    def render_template(self, template_str, none_str="_", path_sep=None):
+    @property
+    def height(self):
+        """ returns height of the current photo version in pixels """
+        return self._info["height"]
+
+    @property
+    def width(self):
+        """ returns width of the current photo version in pixels """
+        return self._info["width"]
+
+    @property
+    def orientation(self):
+        """ returns EXIF orientation of the current photo version as int """
+        return self._info["orientation"]
+
+    @property
+    def original_height(self):
+        """ returns height of the original photo version in pixels """
+        return self._info["original_height"]
+
+    @property
+    def original_width(self):
+        """ returns width of the original photo version in pixels """
+        return self._info["original_width"]
+
+    @property
+    def original_orientation(self):
+        """ returns EXIF orientation of the original photo version as int """
+        return self._info["original_orientation"]
+
+    @property
+    def original_filesize(self):
+        """ returns filesize of original photo in bytes as int """
+        return self._info["original_filesize"]
+
+    def render_template(
+        self,
+        template_str,
+        none_str="_",
+        path_sep=None,
+        expand_inplace=False,
+        inplace_sep=None,
+    ):
         """Renders a template string for PhotoInfo instance using PhotoTemplate
 
         Args:
@@ -650,12 +704,22 @@ class PhotoInfo:
             none_str: a str to use if template field renders to None, default is "_".
             path_sep: a single character str to use as path separator when joining 
                 fields like folder_album; if not provided, defaults to os.path.sep
+            expand_inplace: expand multi-valued substitutions in-place as a single string 
+                instead of returning individual strings
+            inplace_sep: optional string to use as separator between multi-valued keywords
+                with expand_inplace; default is ','
         
         Returns:
             ([rendered_strings], [unmatched]): tuple of list of rendered strings and list of unmatched template values
         """
         template = PhotoTemplate(self)
-        return template.render(template_str, none_str, path_sep)
+        return template.render(
+            template_str,
+            none_str=none_str,
+            path_sep=path_sep,
+            expand_inplace=expand_inplace,
+            inplace_sep=inplace_sep,
+        )
 
     @property
     def _longitude(self):
@@ -754,6 +818,13 @@ class PhotoInfo:
             "exif": exif,
             "score": score,
             "intrash": self.intrash,
+            "height": self.height,
+            "width": self.width,
+            "orientation": self.orientation,
+            "original_height": self.original_height,
+            "original_width": self.original_width,
+            "original_orientation": self.original_orientation,
+            "original_filesize": self.original_filesize,
         }
         return yaml.dump(info, sort_keys=False)
 
@@ -814,6 +885,13 @@ class PhotoInfo:
             "exif": exif,
             "score": score,
             "intrash": self.intrash,
+            "height": self.height,
+            "width": self.width,
+            "orientation": self.orientation,
+            "original_height": self.original_height,
+            "original_width": self.original_width,
+            "original_orientation": self.original_orientation,
+            "original_filesize": self.original_filesize,
         }
         return json.dumps(pic)
 
